texture gTexture0           < string textureState="0,Texture"; >;
texture mask;
texture snowTexture;
float2 roadSize = float2(1.0f,1.0f);
float4x4 gWorld : WORLD;
float4x4 gView : VIEW;
float4x4 gProjection : PROJECTION;
float4x4 gWorldView : WORLDVIEW;
sampler2D Sampler0: register(s0) = sampler_state
{
    Texture         = (gTexture0);
    MinFilter       = Linear;
    MagFilter       = Linear;
    MipFilter       = Linear;
};    
sampler2D SamplerMask = sampler_state
{
    Texture = (mask);
};

sampler2D SamplerSnow = sampler_state
{
    Texture = (snowTexture);
};

struct VSInput
{
    float3 Position : POSITION0;
    float3 Normal : NORMAL0;
    float4 Diffuse : COLOR0;
    float2 TexCoord : TEXCOORD0;
};

struct PSInput
{
    float4 Position : POSITION;
    float2 TexCoord : TEXCOORD0;
    float2 Pos : TEXCOORD1;
};

PSInput VertexShaderFunction(VSInput VS )
{
    PSInput PS = (PSInput)0;
    float4 worldPos = mul(float4(VS.Position.xyz, 1.0f), gWorld);
    float4 viewPos = mul(worldPos, gView);
    float4 Projection = mul(viewPos, gProjection);

    PS.Position = Projection;
    PS.TexCoord = VS.TexCoord;
    PS.Pos = VS.Position.xy;
    return PS;
}

float4 PixelShaderFunction(PSInput PS) : COLOR0
{
    float4 sourceColor = tex2D(Sampler0, PS.TexCoord);
    sourceColor.rgb *= 0.5f;
    float xValue, yValue;
    if (PS.Pos.x > 0) xValue = abs(PS.Pos.x)/(roadSize[0]/2)*0.25f+0.5;
    else xValue = abs(PS.Pos.x)/(roadSize[0]/2)*0.25f;
    if (PS.Pos.y > 0) yValue = abs(PS.Pos.y)/(roadSize[1]/2)*0.25f+0.5;
    else yValue = abs(PS.Pos.y)/(roadSize[1]/2)*0.25f;  
    float4 maskColor = tex2D(SamplerMask, float2(yValue, xValue));
    float4 snowColor = tex2D(SamplerSnow, PS.TexCoord);
    sourceColor.rgb = lerp(snowColor.rgb*0.5, sourceColor.rgb, maskColor.r);
    return sourceColor;
}

technique cam_screen_world_mrt
{
    pass P0
    {
        AlphaBlendEnable = true;
        DepthBias = -0.0001;
        VertexShader = compile vs_2_0 VertexShaderFunction();
        PixelShader = compile ps_2_0 PixelShaderFunction();	
    }

}    